pub struct LegacyReaction {
pub action: String,
pub reference: String,
pub reference_inbox_id: Option<String>,
pub schema: String,
pub content: String,
}Fields
action: StringThe action of the reaction (“added” or “removed”)
reference: StringThe message ID for the message that is being reacted to
reference_inbox_id: Option<String>The inbox ID of the user who sent the message that is being reacted to
schema: StringThe schema of the content (“unicode”, “shortcode”, or “custom”)
content: StringThe content of the reaction
Implementations
Sourceimpl LegacyReaction
impl LegacyReaction
pub fn decode(content: &[u8]) -> Option<LegacyReaction>