pub fn encrypt_attachment(
attachment: Attachment,
) -> Result<EncryptedAttachment, CodecError>Expand description
Encrypts an attachment for storage as a remote attachment.
pub fn encrypt_attachment(
attachment: Attachment,
) -> Result<EncryptedAttachment, CodecError>Encrypts an attachment for storage as a remote attachment.