RemoteAttachment

Type Alias RemoteAttachment 

pub type RemoteAttachment = RemoteAttachmentInfo;
The main content type for remote attachments.

This is a type alias for RemoteAttachmentInfo from the proto definitions, allowing the same type to be used for both single remote attachments and entries in [MultiRemoteAttachment].

Aliased Type

pub struct RemoteAttachment {
    pub content_digest: String,
    pub secret: Vec<u8>,
    pub nonce: Vec<u8>,
    pub salt: Vec<u8>,
    pub scheme: String,
    pub url: String,
    pub content_length: Option<u32>,
    pub filename: Option<String>,
}

Fields

content_digest: String

The SHA256 hash of the remote content

secret: Vec<u8>

A 32 byte array for decrypting the remote content payload

nonce: Vec<u8>

A byte array for the nonce used to encrypt the remote content payload

salt: Vec<u8>

A byte array for the salt used to encrypt the remote content payload

scheme: String

The scheme of the URL. Must be “https://"

url: String

The URL of the remote content

content_length: Option<u32>

The size of the encrypted content in bytes (max size of 4GB)

filename: Option<String>

The filename of the remote content